Learn R Programming

iplots (version 1.0-3)

ibox: Interactive Box Plot

Description

This function creates a new interactive box plot from the given data.

Usage

ibox(x, y=NULL, ...)

Arguments

x
Vector of numbers or data frame containing the variables
y
A factor to specify groups for y-by-x boxplot
...
All additional parameters are passed to iplot.opt. Many of the parameters used in plot are supported.

Value

  • Resulting plot object.

Details

Creates either a regular boxplot (if y is not specified) or `x-by-y boxplot (if y is specified). In the latter case both x and y must be of the same length. Additional parameters: [object Object]

See Also

ihist, ibar, iplot.list, iplot.opt

Examples

Run this code
data(iris)
attach(iris)
ibox(Petal.Length)
ibox(Sepal.Length,Species)

Run the code above in your browser using DataLab