Learn R Programming

iplots (version 1.1-6)

imosaic: Interactive Mosaic Plot

Description

This function creates a new interactive mosaic plot from the given data.

Usage

imosaic(...)

Arguments

...
All unnamed parameters are treated as variables to display. Additional parameters are passed to iplot.opt. The parameter "type" selects the variation of the mosaic plot. Valid

Value

  • Resulting plot object.

Details

The plot can be used either in the form imosaic(df) to plot a list or data frame of variables contained in df or imosaic(x, y, z) to plot variables x, y and z.

Additional parameters: [object Object]

See Also

ihist, ibar, iplot.list, iplot.opt

Examples

Run this code
library(MASS)
data(Cars93)
attach(Cars93)
imosaic(AirBags,Cylinders,Origin)
imosaic(AirBags,Cylinders,Origin,type="mul")
iplot.location(300,100,TRUE)

Run the code above in your browser using DataLab