Learn R Programming

iplots (version 1.0-3)

iplot: Interactive Scatterplot

Description

This function creates a new interactive scatterplot from the given data.

Usage

iplot(x, y=NULL, xlab=NULL, ylab=NULL, ...)

Arguments

x
Data for the x axis. It can be either a vector of values or a variable of an iset. If y is not given, this must be a list of one of these.
y
Data for the y axis. It can be either a vector of values or a variable of an iset.
xlab
Name for x variable.
ylab
Name for y variable.
...
All additional parameters are passed to iplot.opt. Many of the parameters used in plot are supported.

Value

  • Resulting plot object.

Details

Creates an interactive scatterplot. Additional parameters: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object] Default values: changePtDiamBy=2, customFieldBg=FALSE, COL_CUSTOMBG="white", drawAxes=TRUE, equiscale=FALSE, minimalDiam=1, ptDiam=3, spaceprop=1.1

See Also

ihist, ibar, iplot.list, iplot.opt

Examples

Run this code
data(iris)
attach(iris)
iplot(Sepal.Width,Petal.Width)
iplot(Sepal.Width/Sepal.Length, Species)

Run the code above in your browser using DataLab