Learn R Programming

iplots (version 1.1-1)

iplot.manip: iPlot manipulation functions

Description

The following functions are used to mainpulate iplots. They are NOT part of the official API and may disappear without warning. Most of them are legacy functions introduced before iplot.opt was available.

iplot.backend retrieves or sets the iPlots back-end. iplot.resetZoom reset zoom iplot.rotate set plot rotation iplot.setExtendedQuery set text for extended query iplot.zoomIn zoom into specified area iplot.zoomOut zoom out (the coordinates are ignored as the zoom is heararchical)

iplot.location get or set the location of the iplot

Usage

iplot.backend(type = NULL)
iplot.resetZoom() 
iplot.rotate(i) 
iplot.setExtendedQuery(str, plotID=.iplot.curid) 
iplot.zoomIn(x1, y1, x2, y2) 
iplot.zoomOut(x, y)
iplot.location(x, y, relative=FALSE, plot=iplot.cur())
print.iobj(x, ...) 
print.iplot(x, ...)

Arguments

i
rotation orientation
plotID
plot ID (number)
str
string to show on extended query or FALSE or NULL to disable extended query
type
back-end type - one of "awt", "swing" or "opengl" (or any unambiguous first part hereof) to set the type or NULL to retrieve the current back-end type
x1
basis coordinate for the x axis
y1
basis coordinate for the y axis
x2
edge coordinate for the x axis
y2
edge coordinate for the y axis
x
object to print or x-coordinate
y
y-coordinate
plot
plot to query or move (id or object)
relative
can be TRUE, FALSE or another plot
...
additional parameters