iset and
ivar. The iset object encapsuletes an iSets which
can be thought of as a kind of special data frame that allows linking
of all variables contained therein. Each variable (or column in
data.frame-speech) is represented by an ivar object
encapsulating an iVar. An instance of a ivar class can be use to create new iplots or
update data in the existing iplots. Convenience operators on both
ivar and iset objects include those such as
length, subsetting and subassignment and therefor from user's
point of view it is possible to use them transparently a data frames
(iSet) or vectors (iVar). In addition, iSet supports methods such as
names or dim.
iset returns the object corresponding to a given iSet.
isets returs objects for all iSets
iset(which=iset.cur())
isets()
`[[.iset`(x, i)
`$.iset`(x, name)
`[[<-.iset`(x, i, value)
`[.iset`(x, i = 1:(dim(x)[1]), j = 1:length(x))
`[<-.iset`(x, i = 1:(dim(x)[1]), j = 1:length(x), value)
`names<-.iset`(x, value)
names.iset(x)
length.iset(x)
dim.iset(x)ivar, iset.cur