You can get the iset object by calling the iset function. An
iset object can be used in a way similar to data frames, so subsetting
and other operations work as expected. Subassignment is always done
"live", so changeing parts of the data will cause plots to be updated
accordingly.
There is always exactly one current iSet. An initial iSet called
"default" is created when the iplots library is loaded. All new
iPlots are created using the current iSet. The set of functions
described here allow the manipulation of iSets.
Note that changing the iSet also has an effect on
iplot.list and iobj.list since iPlots
are linked to their iSets.
iset.new creates a new iSet and makes it current
iset.list returns all iSets
iset.cur returns the ID of the current iSet
iset.next and iset.prev return the ID
of the next resp. previous iSet in the list relative to the iSet
specified by the argument.
iset.set makes the iSet with the specified ID current.
iset.rm removes the given iSet and all associated plots.
Note that this may cause the current set ID may change (even if some
other iSet is removed).
print.iset prints an iSet object.
iset.new(name=NULL, payload=NULL)
iset.list()
iset.cur()
iset.next(which=iset.cur())
iset.prev(which=iset.cur())
iset.set(which=iset.next())
iset.rm(which=iset.cur())
## S3 method for class 'iset':
print(x, ...)NULL if an empty iSet is desired.printiset, iplot.list, iobj.list