iabline: Add a straight line to the current iPlot.
Description
This function adds one straight line through the current iPlot.Usage
iabline(a, b, ...)
iabline(coef=, ...)
iabline(reg=, ...)
Arguments
a, b
the intercept and slope
coef
a vector of length two giving the intercept and slope
reg
an object with a coef component
synopsis
iabline(a = NULL, b = NULL, reg = NULL, coef = NULL, ..., plot = iplot.cur())