This function creates a new interactive hammock plot. Please note that
a hammock plot was not necessarily designed to support highlighting, so
it may be of limited use. It was created as a proof of the iBase
concept which makes it very easy to implement new interactive plots.
Usage
ihammock(vars, ...)
Arguments
vars
list of factors to display
...
All additional parameters are passed to
iplot.opt. All unnamed parameters are assumed to be
data to plot.