This function creates a new interactive mosaic plot from the given data.
Usage
imosaic(...)
Arguments
...
All unnamed parameters are treated as variables to
display. Additional parameters are passed to
iplot.opt.
The parameter "type" selects the variation of the mosaic
plot. Valid
Value
Resulting plot object.
Details
The plot can be used either in the form imosaic(df) to plot
a list or data frame of variables contained in df or
imosaic(x, y, z) to plot variables x, y and
z.