Learn R Programming

iplots (version 1.1-2)

imosaic: Interactive Mosaic Plot

Description

This function creates a new interactive mosaic plot from the given data.

Usage

imosaic(vars, ..., type="observed")

Arguments

vars
list of variables/factors or a single variable/factor
...
All additional parameters are passed to iplot.opt. All unnamed parameters are treated as variables to display.
type
selects the variation of the mosaic plot. Valid values are "observed", "expected", "fluctuation", "same.bin.size" and "multiple.barchart". Partial matching is used, so first letter is sufficient.

Value

  • Resulting plot object.

synopsis

imosaic(...)

Details

Additional parameters: [object Object]

See Also

ihist, ibar, iplot.list, iplot.opt

Examples

Run this code
library(MASS)
data(Cars93)
attach(Cars93)
imosaic(AirBags,Cylinders,Origin)
imosaic(AirBags,Cylinders,Origin,type="mul")
iplot.location(300,100,TRUE)

Run the code above in your browser using DataLab