Learn R Programming

iplots (version 1.0-3)

imosaic: Interactive Mosaic Plot

Description

This function creates a new interactive mosaic plot from the given data.

Usage

imosaic(vars, ...)

Arguments

vars
list of variables/factors or a single variable/factor
...
All additional parameters are passed to iplot.opt. Many of the parameters used in plot are supported.

Value

  • Resulting plot object.

Details

Additional parameters: [object Object]

See Also

ihist, ibar, iplot.list, iplot.opt

Examples

Run this code
library(MASS)
data(Cars93)
attach(Cars93)
imosaic(data.frame(AirBags,Cylinders,Origin))

Run the code above in your browser using DataLab