Learn R Programming

iplots (version 1.0-5)

iplot.manip: iPlot manipulation functions

Description

The following functions are used to mainpulate iplots. They are NOT part of the official API and may disappear without warning.

iplot.backend retrieves or sets the iPlots back-end. iplot.resetAxes reset all axes to their defaults iplot.resetXaxis reset major X axis to its default iplot.resetYaxis reset major Y axis to its default iplot.resetZoom reset zoom iplot.rotate set plot rotation iplot.setExtendedQuery set text for extended query iplot.showVars show window with current variable (unimplemented unless KLIMT plugin is loaded) iplot.zoomIn zoom into specified area iplot.zoomOut zoom out (the coordinates are ignored as the zoom is heararchical)

Usage

iplot.backend(type = NULL)
iplot.resetAxes(ipl = lastPlot) 
iplot.resetXaxis(ipl = lastPlot) 
iplot.resetYaxis(ipl = lastPlot) 
iplot.resetZoom() 
iplot.rotate(i) 
iplot.setExtendedQuery(str) 
iplot.showVars() 
iplot.zoomIn(x1, y1, x2, y2) 
iplot.zoomOut(x, y) 
print.iobj(x, ...) 
print.iplot(x, ...)

Arguments

ipl
plot to operate on
i
rotation orientation
str
string to show on extended query
type
back-end type - one of "awt", "swing" or "opengl" (or any unambiguous first part hereof) to set the type or NULL to retrieve the current back-end type
x1
basis coordinate for the x axis
y1
basis coordinate for the y axis
x2
edge coordinate for the x axis
y2
edge coordinate for the y axis
x
object to print
y
unused
...
additional parameters