iplot.opt was
available. iplot.backend retrieves or sets the iPlots back-end.
iplot.resetZoom reset zoom
iplot.rotate set plot rotation
iplot.setExtendedQuery set text for extended query
iplot.zoomIn zoom into specified area
iplot.zoomOut zoom out (the coordinates are ignored as the zoom
is heararchical)
iplot.location get or set the location of the iplot
iplot.size get or set the size of an iplot plot
iplot.backend(type = NULL)
iplot.resetZoom()
iplot.rotate(i)
iplot.setExtendedQuery(str, plotID=.iplot.curid)
iplot.zoomIn(x1, y1, x2, y2)
iplot.zoomOut(x, y)
iplot.location(x, y, relative=FALSE, plot=iplot.cur())
iplot.size(width, height, plot=iplot.cur())
print.iobj(x, ...)
print.iplot(x, ...)FALSE or NULL to disable extended query"awt", "swing" or
"opengl" (or any unambiguous first part hereof) to set the
type or NULL to retrieve the current back-end typex axisy axisx axisy axisTRUE, FALSE or another plotiplot.location, iplot.size: those functions either query
or set the location or size of the plot. If either of the coordinates
is missing, the size/location in that coordinate will not be changed.
If both coordinates are missing, the functions have no side effect and
just return the current size (iplot.size) or location and size
(iplot.location) as named vectors (x, y for
location and width, height for size). iplot.backend determines the back-end used by iplots. The
choices are awt, swing an dopengl. Not all
back-ends are available on all platforms. AWT is the most
compatible back-end and available on all platforms, Swing has
more modern look and feel and OpenGL sacrifices text rendering
quality for speed (i.e. OpenGL backend is best for large data). When
no backend is specified, the function has no side effect and just
returns the currently requested back-end. Currently there is no
indication whether the back-end request was honored or not. If a
backend is not supported, the request is silently ignored.